# Discovering AI Agents from Amazon Bedrock
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#prerequisites)
  * [Step 1: Create a User for SAP LeanIX](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-1:-create-a-user-for-sap-leanix)
  * [Step 2: Set Permissions for the User](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-2:-set-permissions-for-the-user)
  * [Step 3: Review User Details](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-3:-review-user-details)
  * [Step 4: Create an Access Key](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-4:-create-an-access-key)
  * [Step 5: Get Region Code Details](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-5:-get-region-code-details)
  * [Step 6: Connect SAP LeanIX to Amazon Bedrock](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock#step-6:-connect-sap-leanix-to-amazon-bedrock)


View all
Integrate SAP LeanIX with Amazon Bedrock Agents and Amazon Bedrock AgentCore to automatically discover your AI agents.
